==> crm-commom-vo-1.1.0.release.jar: com/biz/crm/nebular/sfa/worksign/req/SfaLeaveReqVo.java <==
package com.biz.crm.nebular.sfa.worksign.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;
/**
 * 请假申请 请求vo
 *
 * @author liuhongming
 * @date 2020-10-17 15:00:38
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "SfaLeaveReqVo", description = "请假申请 ")
public class SfaLeaveReqVo {

    private String id;

    @ApiModelProperty("请假类型 请假类型")
    private String leaveType;

    @ApiModelProperty("请假事由 请假事由")
    private String leaveReason;

    @ApiModelProperty("人员账号 人员账号")
    private String userName;

    @ApiModelProperty("人员姓名 人员姓名")
    private String realName;

//    @ApiModelProperty("职位编码 职位编码")
//    private String posCode;
//
//    @ApiModelProperty("职位名称 职位名称")
//    private String posName;

    @ApiModelProperty("所属组织编码 所属组织编码")
    private String orgCode;

    @ApiModelProperty("所属组织名称 所属组织名称")
    private String orgName;

    @ApiModelProperty("申请日期 申请日期(yyyy-MM-dd HH:mm:dd)")
    private String applicationDate;

    @ApiModelProperty("开始时间 开始时间(yyyy-MM-dd HH)")
    private String beginTime;

    @ApiModelProperty("结束时间 结束时间(yyyy-MM-dd HH)")
    private String endTime;

    @ApiModelProperty("审批状态 审批状态")
    private String bpmStatus;

    @ApiModelProperty("审批状态 多选")
    private List<String> bpmStatusList;

    @ApiModelProperty("日期明细列表")
    private List<SfaApplyTimeInfoReqVo> timeInfoList;

    @ApiModelProperty("请假时长(天)")
    private String leaveDuration;

    @ApiModelProperty("附件集合")
    private List<SfaApplyAttachmentReqVo> attachmentList;


}

==> crm-commom-vo-1.1.3.release.jar: com/biz/crm/nebular/sfa/worksign/req/SfaLeaveReqVo.java <==
package com.biz.crm.nebular.sfa.worksign.req;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.util.List;
/**
 * 请假申请 请求vo
 *
 * @author liuhongming
 * @date 2020-10-17 15:00:38
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "SfaLeaveReqVo", description = "请假申请 ")
public class SfaLeaveReqVo {

    private String id;

    @ApiModelProperty("请假类型 请假类型")
    private String leaveType;

    @ApiModelProperty("请假事由 请假事由")
    private String leaveReason;

    @ApiModelProperty("人员账号 人员账号")
    private String userName;

    @ApiModelProperty("人员姓名 人员姓名")
    private String realName;

    @ApiModelProperty("职位编码 职位编码")
    private String posCode;

    @ApiModelProperty("职位名称 职位名称")
    private String posName;

    @ApiModelProperty("所属组织编码 所属组织编码")
    private String orgCode;

    @ApiModelProperty("所属组织名称 所属组织名称")
    private String orgName;

    @ApiModelProperty("申请日期 申请日期(yyyy-MM-dd HH:mm:dd)")
    private String applicationDate;

    @ApiModelProperty("开始时间 开始时间(yyyy-MM-dd HH)")
    private String beginTime;

    @ApiModelProperty("结束时间 结束时间(yyyy-MM-dd HH)")
    private String endTime;

    @ApiModelProperty("审批状态 审批状态")
    private String bpmStatus;

    @ApiModelProperty("审批状态 多选")
    private List<String> bpmStatusList;

    @ApiModelProperty("日期明细列表")
    private List<SfaApplyTimeInfoReqVo> timeInfoList;

    @ApiModelProperty("请假时长(天)")
    private String leaveDuration;

    @ApiModelProperty("附件集合")
    private List<SfaApplyAttachmentReqVo> attachmentList;


}
